@@ -1,5 +1,5 @@
 package Netscape::Bookmarks::Alias;
-# $Id: Alias.pm,v 1.4 2002/09/23 21:33:34 comdog Exp $
+# $Id: Alias.pm,v 1.7 2007/10/02 07:30:25 comdog Exp $
 
 =head1 NAME
 
@@ -30,19 +30,13 @@ the target link also changes.
 
 use strict;
 
+use base qw( Netscape::Bookmarks::AcceptVisitor Netscape::Bookmarks::Isa );
 use subs qw();
-use vars qw($VERSION $ERROR @EXPORT @EXPORT_OK @ISA %aliases);
+use vars qw($VERSION $ERROR %aliases);
 
 use Exporter;
 
-use Netscape::Bookmarks::Link;
-use Netscape::Bookmarks::AcceptVisitor;
-
-($VERSION) = q$Revision: 1.4 $ =~ m/(\d+\.\d+)\s*$/;
-
-@EXPORT    = qw();
-@EXPORT_OK = qw();
-@ISA       = qw(Netscape::Bookmarks::AcceptVisitor);
+$VERSION = sprintf "%d.%02d", q$Revision: 1.7 $ =~ m/(\d+) \. (\d+)/xg;
 
 =item $obj = Netscape::Bookmarks::Alias->new( ALIASID )
 
@@ -183,15 +177,14 @@ sub remove
 
 =head1 AUTHOR
 
-brian d foy E<lt>bdfoy@cpan.orgE<gt>
+brian d foy C<< <bdfoy@cpan.org> >>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
+Copyright (c) 2002-2007 brian d foy.  All rights reserved.
 
-If you send me modifications or new features, I will do
-my best to incorporate them into future versions.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
