@@ -1,5 +1,5 @@
 package Netscape::Bookmarks::Category;
-# $Id: Category.pm,v 1.5 2002/09/24 01:29:32 comdog Exp $
+# $Id: Category.pm,v 1.8 2007/10/02 07:30:29 comdog Exp $
 
 =head1 NAME
 
@@ -52,16 +52,13 @@ title of the bookmarks file.
 =cut
 
 use strict;
-use subs qw();
-use vars qw($VERSION $ERROR @EXPORT @EXPORT_OK @ISA $LAST_ID %IDS);
 
-use Netscape::Bookmarks;
-use Netscape::Bookmarks::AcceptVisitor;
+use base qw( Netscape::Bookmarks::AcceptVisitor Netscape::Bookmarks::Isa );
+use subs qw();
+use vars qw( $VERSION $ERROR $LAST_ID %IDS );
 
 use Exporter;
 
-use URI::URL;
-
 use constant START_LIST      => '<DL><p>';
 use constant END_LIST        => '</DL><p>';
 use constant START_LIST_ITEM => '<DT>';
@@ -70,14 +67,10 @@ use constant FOLDED_TRUE     => 1;
 use constant FOLDED_FALSE    => 0;
 use constant TRUE            => 'true';
 
-($VERSION) = q$Revision: 1.5 $ =~ m/(\d+\.\d+)\d*$/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.8 $ =~ m/(\d+) \. (\d+)/xg;
 %IDS     = ();
 $LAST_ID = -1;
 
-@EXPORT    = qw();
-@EXPORT_OK = qw();
-@ISA       = qw(Netscape::Bookmarks::AcceptVisitor);
-
 =item Netscape::Bookmarks::Category-E<gt>new( \%hash )
 
 The new method creates a Category.  It takes a hash reference
@@ -636,17 +629,14 @@ __END__
 
 =head1 AUTHOR
 
-brian d foy E<lt>bdfoy@cpan.orgE<gt>
+brian d foy C<< <bdfoy@cpan.org> >>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-This program is free software; you can redistribute it
-and/or modify it under the same terms as Perl itself.
+Copyright (c) 2002-2007 brian d foy.  All rights reserved.
 
-If you send me modifications or new features, I will do
-my best to incorporate them into future versions. You can
-interact with the Sourceforge porject for this module at
-http://sourceforge.net/projects/nsbookmarks/.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
